/////////////////////////////////////////////////////////////////
// crex: CR EXcluder
//
// A program to convert MS-DOS ascii files to UNIX ascii files
//
//     -> CR (carriage return) characters are removed
//
// USAGE: 
// crex -p
// crex [source_file_path] [destination_file_path]
//
// Coded by Rick Burton 10/23/1999
////////////////////////////////////////////////////////////////


#include <stdio.h>
#include <stdlib.h>	// ANSI Standard C file
#include <string.h>

/////////////////////////////////////////////////////////////////
// print_use(): print USEAGE info to the screen
//
/////////////////////////////////////////////////////////////////
void print_use(void)
{
    printf("\nUSEAGE:");
    printf("\n\n   crex -p");
    printf("\n\n\tRuns the utility in prompted mode.\n");
    printf("\n\n   crex [full_source_path] [full_destination_path]");
    printf("\n\n\tRuns the utility in command line mode.\n\n");
}

int main(int argc, char *argv[])
{
    FILE *in_file;         // input file
    FILE *out_file;        // output file
    int ch;                // character or EOF flag from input
    char source_file[256]; // source file string
    char dest_file[256];   // destination file string

	if (system("cls"))
		system("clear");
    
	switch (argc) {

	// utility name only Entered, print useage to screen
    //
	case 1:
	    print_use();
	    exit(0);
	    break;

	// if one parameter is Entered, check for "-p"
	// OR print error and useage to screen
	//
	case 2:
	    if ((argv[1][0] == '-') && (argv[1][1] == 'p')) {
        // get source path from user
        //
			printf("\nEnter file to convert: ");
			fgets(source_file, sizeof(source_file), stdin);
			source_file[strlen(source_file)-1] = '\0';

			// test for existing path
			//
			in_file = fopen(source_file, "rb");
			if (in_file == NULL) {
				printf("\n\nCannot open %s... check path?\n", source_file);
				exit(8);
			}

			// get destination path from user
			//
			printf("\nEnter file to create: ");
			fgets(dest_file, sizeof(dest_file), stdin);
			dest_file[strlen(dest_file)-1] = '\0';

			// test for same source and destination
			//
			if (strcmp(source_file, dest_file) == 0) {
				printf("\nSource and destination cannot be the same file.\n\n");
				exit(8);
			}

			// test for existing path
			//
			out_file = fopen(dest_file, "wb");
			if (out_file == NULL) {
				printf("\n%s cannot be created... check path?\n", dest_file);
				exit(8);
			}
	    } else {
            // oops, didn't type "-p" for the switch
            //
			printf("\n** Wrong switch! **");
			printf("\n*******************\n");
			print_use();
	    }
	    break;

    // command line mode: pass a source path and destination path
    // at the command line
    //
	case 3:
        // get source and destination from command line args
        //
	    strcpy(source_file, argv[1]);
	    strcpy(dest_file, argv[2]);

        // test for existing path
        //
	    in_file = fopen(argv[1], "rb");
	    if (in_file == NULL) {
			printf("\n\nCannot open %s... check path?\n", source_file);
			exit(8);
		// test for same source and destination
        //
	    } else if (strcmp(source_file, dest_file) == 0) {
			printf("\nSource and destination cannot be the same file.\n\n");
			exit(8);
	    }

        // test for existing path
        //
	    out_file = fopen(argv[2], "wb");
	    if (out_file == NULL) {
			printf("\n%s cannot be created... check path?\n", dest_file);
			exit(8);
	    }
	    break;

        // oops, we just typed too many parameters here
        //
	default:
	    printf("\n** TOO MANY PARAMETERS **");
	    printf("\n*************************\n");
	    print_use();
	    exit(0);
	    break;
    }

    while (1) {
		ch = fgetc(in_file);
		if (ch == EOF) {         // get characters until the end of file
			break;
		} else if (ch != 13) {   // don't pass them through if they are a CR
			fputc(ch, out_file);
		}
    }

    printf("\nSuccess!\n\n");

    fclose(in_file);
    fclose(out_file);
    
    return(0);
} 

